@@ -240,7 +240,7 @@ TGUI_MODULE_EXPORT namespace tgui
         ///
         /// The default width is the value the scrollbar has on construction or the size of the texture once a texture is set.
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        TGUI_NODISCARD float getDefaultWidth();
+        TGUI_NODISCARD float getDefaultWidth() const;
 
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -431,7 +431,7 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns whether the left mouse button has been pressed on top of the thumb of the scrollbar
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        bool isMouseDownOnThumb() const;
+        TGUI_NODISCARD bool isMouseDownOnThumb() const;
 
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -440,7 +440,7 @@ TGUI_MODULE_EXPORT namespace tgui
         ///
         /// The scrollbar is visible when auto hide is disabled or when the maximum is higher than the viewport size
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        bool isShown() const;
+        TGUI_NODISCARD bool isShown() const;
 
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
