@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2023 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,9 +26,7 @@
 #include <TGUI/extlibs/IncludeSDL.hpp>
 #include <TGUI/Backend/Renderer/SDL_Renderer/BackendRenderTargetSDL.hpp>
 
-#if TGUI_BUILD_AS_CXX_MODULE
-    import tgui;
-#else
+#if !TGUI_BUILD_AS_CXX_MODULE
     #include <TGUI/Backend/Renderer/BackendText.hpp>
     #include <TGUI/Backend/Window/Backend.hpp>
     #include <TGUI/Container.hpp>
@@ -133,6 +131,9 @@ namespace tgui
     void BackendRenderTargetSDL::drawVertexArray(const RenderStates& states, const Vertex* vertices,
         std::size_t vertexCount, const unsigned int* indices, std::size_t indexCount, const std::shared_ptr<BackendTexture>& texture)
     {
+        if (vertexCount == 0)
+            return;
+
         SDL_Texture* textureSDL = nullptr;
         if (texture)
         {
@@ -149,6 +150,14 @@ namespace tgui
             verticesSDL[i].position.y = transformedPosition.y;
         }
 
+#if SDL_MAJOR_VERSION >= 3
+        static_assert(sizeof(Vertex::Color) == sizeof(SDL_Color), "SDL_Color requires same memory layout as tgui::Vertex::Color for cast to work");
+        SDL_RenderGeometryRaw(m_renderer, textureSDL,
+                              &vertices->position.x, sizeof(Vertex),
+                              reinterpret_cast<const SDL_Color*>(&vertices->color), sizeof(Vertex),
+                              &vertices->texCoords.x, sizeof(Vertex),
+                              static_cast<int>(vertexCount), indices, static_cast<int>(indexCount), sizeof(unsigned int));
+#else
         // We use SDL_RenderGeometry instead of SDL_RenderGeometryRaw because it's easier and because the signature of
         // the SDL_RenderGeometryRaw function is different in SDL 2.0.18 and SDL >= 2.0.20
         static_assert(sizeof(int) == sizeof(unsigned int), "Size of 'int' and 'unsigned int' must be identical for cast to work");
@@ -156,6 +165,7 @@ namespace tgui
         SDL_RenderGeometry(m_renderer, textureSDL,
                            reinterpret_cast<const SDL_Vertex*>(verticesSDL.data()), static_cast<int>(vertexCount),
                            reinterpret_cast<const int*>(indices), static_cast<int>(indexCount));
+#endif
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
