@@ -96,7 +96,11 @@ namespace tgui
         case SDLK_SEMICOLON:    return Event::KeyboardKey::Semicolon;
         case SDLK_COMMA:        return Event::KeyboardKey::Comma;
         case SDLK_PERIOD:       return Event::KeyboardKey::Period;
+#if SDL_MAJOR_VERSION >= 3
+        case SDLK_APOSTROPHE:   return Event::KeyboardKey::Quote;
+#else
         case SDLK_QUOTE:        return Event::KeyboardKey::Quote;
+#endif
         case SDLK_SLASH:        return Event::KeyboardKey::Slash;
         case SDLK_BACKSLASH:    return Event::KeyboardKey::Backslash;
         case SDLK_EQUALS:       return Event::KeyboardKey::Equal;
@@ -514,9 +518,14 @@ namespace tgui
                         eventProcessed = true;
                     }
 #if SDL_MAJOR_VERSION >= 3
-                    else if ((event.type == SDL_EVENT_WINDOW_PIXEL_SIZE_CHANGED) || (event.type == SDL_EVENT_WINDOW_MOUSE_LEAVE))
+                    else if ((event.type == SDL_EVENT_WINDOW_PIXEL_SIZE_CHANGED) || (event.type == SDL_EVENT_WINDOW_EXPOSED)
+                          || (event.type == SDL_EVENT_WINDOW_MOUSE_ENTER) || (event.type == SDL_EVENT_WINDOW_MOUSE_LEAVE)
+                          || (event.type == SDL_EVENT_WINDOW_FOCUS_GAINED) || (event.type == SDL_EVENT_WINDOW_FOCUS_LOST))
 #else
-                    else if ((event.type == SDL_WINDOWEVENT) && ((event.window.event == SDL_WINDOWEVENT_SIZE_CHANGED) || (event.window.event == SDL_WINDOWEVENT_LEAVE)))
+                    else if ((event.type == SDL_WINDOWEVENT)
+                          && ((event.window.event == SDL_WINDOWEVENT_SIZE_CHANGED) || (event.window.event == SDL_WINDOWEVENT_EXPOSED)
+                           || (event.window.event == SDL_WINDOWEVENT_ENTER) || (event.window.event == SDL_WINDOWEVENT_LEAVE)
+                           || (event.window.event == SDL_WINDOWEVENT_FOCUS_GAINED) || (event.window.event == SDL_WINDOWEVENT_FOCUS_LOST)))
 #endif
                     {
                         eventProcessed = true;
