@@ -214,7 +214,7 @@ namespace tgui
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-    std::size_t ChatBox::getLineAmount()
+    std::size_t ChatBox::getLineAmount() const
     {
         return m_lines.size();
     }
@@ -239,7 +239,7 @@ namespace tgui
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-    std::size_t ChatBox::getLineLimit()
+    std::size_t ChatBox::getLineLimit() const
     {
         return m_maxLines;
     }
