@@ -118,8 +118,8 @@ namespace tgui
         m_listView->setSize({"100% - 20", "#TGUI_INTERNAL$EditBoxFilename#.top - top - 10"});
 
         m_listView->addColumn("Name", 0);
-        m_listView->addColumn("Size", 75, ListView::ColumnAlignment::Right);
-        m_listView->addColumn("Modified", 145, ListView::ColumnAlignment::Right);
+        m_listView->addColumn("Size", 75, HorizontalAlignment::Right);
+        m_listView->addColumn("Modified", 145, HorizontalAlignment::Right);
         m_listView->setColumnExpanded(0, true);
 
         if (m_iconLoader->supportsSystemIcons())
