@@ -39,6 +39,8 @@
 
 #include <memory>
 #include <chrono>
+#include <cstring>
+#include <map>
 
 #if TGUI_HAS_BACKEND_SFML_GRAPHICS
     #include <SFML/Graphics/RenderTexture.hpp>
@@ -55,10 +57,13 @@
                     std::unique_ptr<sf::RenderTexture> target; \
                     if (std::dynamic_pointer_cast<tgui::BackendRendererSFML>(tgui::getBackend()->getRenderer())) \
                     { \
-                        target = std::make_unique<sf::RenderTexture>(); \
-                        (void)target->create({width, height}); \
-                        guiUniquePtr = std::make_unique<tgui::SFML_GRAPHICS::Gui>(*target); \
-                        guiPtr = guiUniquePtr.get(); \
+                        auto optionalTarget = sf::RenderTexture::create({width, height}); \
+                        if (optionalTarget) \
+                        { \
+                            target = std::make_unique<sf::RenderTexture>(std::move(*optionalTarget)); \
+                            guiUniquePtr = std::make_unique<tgui::SFML_GRAPHICS::Gui>(*target); \
+                            guiPtr = guiUniquePtr.get(); \
+                        } \
                     } \
                     tgui::BackendGui& gui{*guiPtr}; \
                     gui.removeAllWidgets(); \
